<template>
  <a-card :bordered='false'  title='备件领用需求'>
    <div class='table-page-search-wrapper'>
      <a-form layout='inline' @keyup.enter.native='searchQuery'>
        <a-row :gutter='24'>
          <a-col :xl='6' :lg='7' :md='8' :sm='24'>
            <a-form-item label='单据号'>
              <j-input placeholder='请输入单据号' v-model='queryParam.num'></j-input>
            </a-form-item>
          </a-col>

          <a-col :xl='6' :lg='7' :md='8' :sm='24'>
            <a-form-item label='状态'>
              <j-dict-select-tag type='list' v-model='queryParam.status' dictCode='purchase_storage_status'
                                 placeholder='请选择状态' />
            </a-form-item>
          </a-col>
          <a-col :xl='6' :lg='7' :md='8' :sm='24'>
            <span style='float: left;overflow: hidden;' class='table-page-search-submitButtons'>
              <a-button type='primary' @click='searchQuery' icon='search'>查询</a-button>
              <a-button type='primary' @click='searchReset' icon='reload' style='margin-left: 8px'>重置</a-button>

            </span>
          </a-col>
        </a-row>
      </a-form>
    </div>


    <!-- 查询区域-END -->

    <!-- 操作按钮区域 -->
    <div class='table-operator'>
      <a-button @click='handleAdd' type='primary' icon='plus'>新增</a-button>
      <a-button @click='handleSubmit' type='primary' icon='check'
                v-if="selectedRowKeys.length > 0  && (selectionRows[0].status ==='0'  || selectionRows[0].status==='3')">
        提交
      </a-button>
      <a-button v-if="selectedRowKeys.length > 0  && selectionRows[0].status==='1'"
                @click='handleRevocation' type='primary' icon='rollback'>撤回
      </a-button>
    </div>

    <!-- table区域-begin -->
    <div>
      <div class='ant-alert ant-alert-info' style='margin-bottom: 16px;'>
        <i class='anticon anticon-info-circle ant-alert-icon'></i> 已选择 <a
        style='font-weight: 600'>{{ selectedRowKeys.length }}</a>项
        <a style='margin-left: 24px' @click='onClearSelected'>清空</a>
      </div>

      <a-table
        ref='table'
        size='middle'
        bordered
        rowKey='id'
        class='j-table-force-nowrap'
        :scroll='{x:true}'
        :columns='columns'
        :dataSource='dataSource'
        :pagination='ipagination'
        :loading='loading'
        :customRow='clickThenSelect'
        :rowSelection="{selectedRowKeys: selectedRowKeys, onChange: onSelectChange, type:'radio'}"
        @change='handleTableChange'>

        <template slot='htmlSlot' slot-scope='text'>
          <div v-html='text'></div>
        </template>
        <template slot='imgSlot' slot-scope='text,record'>
          <span v-if='!text' style='font-size: 12px;font-style: italic;'>无图片</span>
          <img v-else :src='getImgView(text)' :preview='record.id' height='25px' alt=''
               style='max-width:80px;font-size: 12px;font-style: italic;' />
        </template>
        <template slot='fileSlot' slot-scope='text'>
          <span v-if='!text' style='font-size: 12px;font-style: italic;'>无文件</span>
          <a-button
            v-else
            :ghost='true'
            type='primary'
            icon='download'
            size='small'
            @click='downloadFile(text)'>
            下载
          </a-button>
        </template>

<!--        <span
          slot='action'
          slot-scope='text, record'
        >
          <a v-if="record.status === '0' || record.status === '3'" @click='handleEdit(record)'>编辑</a>
          <a v-if="record.status === '1'" @click='handleApprove(record)'>审批</a>

          <a-divider v-if="record.status === '0' || record.status === '3'" type='vertical' />
        <a-dropdown v-if="record.status === '0' || record.status === '3'">
                        <a class='ant-dropdown-link'>更多 <a-icon type='down'/></a>
                        <a-menu slot='overlay'>
                            <a-menu-item>
                                <a-popconfirm title='确定删除吗?'
                                              @confirm='() => handleDelete(record.id)'>
                                    <a>删除</a>
                                </a-popconfirm>
                            </a-menu-item>

                        </a-menu>
                    </a-dropdown>
        </span>-->
        <span
          slot='action'
          slot-scope='text, record'
        >
          <a v-if="record.status === '0' || record.status === '3'" @click='handleEdit(record)'>编辑</a>
          <a v-if="record.status === '1'" @click='handleApprove(record)'>审批</a>
                <a-divider
                  v-if="record.status == '0' || record.status == '3' || record.status == '1'"
                  type='vertical'
                />
          <a-dropdown>
            <a class='ant-dropdown-link'>更多 <a-icon type='down' /></a>
            <a-menu slot='overlay'>
              <a-menu-item>
                <a @click='handleDetail(record)'>详情</a>
              </a-menu-item>
              <a-menu-item v-if="record.status == '0'||record.status == '3'">
                <a-popconfirm
                  title='确定删除吗?'
                  @confirm='() => handleDelete(record.id)'
                >
                  <a>删除</a>
                </a-popconfirm>
              </a-menu-item>
            </a-menu>
          </a-dropdown>
        </span>
      </a-table>
    </div>
    <a-tabs defaultActiveKey='1'>
      <a-tab-pane tab='领用申请明细单' key='1'>
        <div
          class='table-operator'
          style='margin:-20px'>
          <spare-part-receive-deatil-list :mainId='sparesScrapDetailMainId' />
        </div>

      </a-tab-pane>
    </a-tabs>
    <spare-part-receive-modal ref='modalForm' @ok='modalFormOk' />

    <approvel-modal ref='approvalModalForm' @ok='approvalModalFormOk' @cancel='approvalModalFormOk'></approvel-modal>
  </a-card>
</template>

<script>

import { JeecgListMixin } from '@/mixins/JeecgListMixin'
import SparePartReceiveModal from './modules/sparePartReceive/SparePartReceiveModal'
import '@assets/less/TableExpand.less'
import SparePartReceiveDeatilList from './modules/sparePartReceive/SparePartReceiveDeatilList'
import { getAction, postAction } from '@/api/manage'
import ApprovelModal from '@views/common/ApprovelModal'
export default {
  name: 'SparePartScrapList',
  mixins: [JeecgListMixin],
  components: {
    SparePartReceiveModal,
    SparePartReceiveDeatilList,
    ApprovelModal
  },
  data() {
    return {
      sparesScrapDetailMainId: '',
      selectedMainId: '',
      description: '备件领用管理页面',
      // 表头
      columns: [
        {
          title: '#',
          dataIndex: '',
          key: 'rowIndex',
          width: 60,
          align: 'center',
          customRender: function(t, r, index) {
            return parseInt(index) + 1
          }
        },
        {
          title: '单据号',
          align: 'center',
          dataIndex: 'num'
        },
        {
          title: '状态',
          align: 'center',
          dataIndex: 'status_dictText'
        },
        {
          title: '仓库',
          align: 'center',
          dataIndex: 'warehouseId_dictText'
        },
        {
          title: '领用部门',
          align: 'center',
          dataIndex: 'departId_dictText'
        },
        {
          title: '领用人员',
          align: 'center',
          dataIndex: 'userId_dictText'
        },
        {
          title: '创建人',
          align: 'center',
          dataIndex: 'createBy'
        },
        {
          title: '创建日期',
          align: 'center',
          dataIndex: 'createTime'
        },
        {
          title: '更新人',
          align: 'center',
          dataIndex: 'updateBy'
        },
        {
          title: '更新日期',
          align: 'center',
          dataIndex: 'updateTime'
        },

        {
          title: '备注',
          align: 'center',
          dataIndex: 'remark'
        },
        {
          title: '操作',
          dataIndex: 'action',
          align: 'center',
          fixed: 'right',
          width: 147,
          scopedSlots: { customRender: 'action' }
        }
      ],
      url: {
        submit: 'spare/sparePartReceive/submit',
        list: '/spare/sparePartReceive/list',
        delete: '/spare/sparePartReceive/delete',
        deleteBatch: 'spare/sparePartReceive/deleteBatch',
        exportXlsUrl: '/spare/sparePartReceive/exportXls',
        importExcelUrl: '/spare/sparePartReceive/importExcel',
        revocation: '/spare/sparePartReceive/revocation',
        reject: 'spare/sparePartReceive/reject',
        approval: 'spare/sparePartReceive/approval'
      },
      /* 分页参数 */
      ipagination: {
        current: 1,
        pageSize: 5,
        pageSizeOptions: ['5', '10', '50'],
        showTotal: (total, range) => {
          return range[0] + '-' + range[1] + ' 共' + total + '条'
        },
        showQuickJumper: true,
        showSizeChanger: true,
        total: 0
      },
      dictOptions: {},
      superFieldList: []
    }
  },
  created() {
    this.getSuperFieldList()
  },
  computed: {
    importExcelUrl: function() {
      return `${window._CONFIG['domianURL']}/${this.url.importExcelUrl}`
    }
  },
  methods: {
    initDictConfig() {
    },
    clickThenSelect(record) {
      return {
        on: {
          click: () => {
            this.onSelectChange(record.id.split(','), [record])
          }
        }
      }
    },
    onClearSelected() {
      this.selectedRowKeys = []
      this.selectionRows = []
      this.selectedMainId = ''
      this.sparesScrapDetailMainId = ''
    },

    onSelectChange(selectedRowKeys, selectionRows) {
      if (selectedRowKeys.length == 1) {

        this.sparesScrapDetailMainId = selectionRows[0]['id']
      } else {

        this.sparesScrapDetailMainId = ''
      }
      this.selectedMainId = selectedRowKeys[0]
      this.selectedRowKeys = selectedRowKeys
      this.selectionRows = selectionRows
    },

    searchReset() {
      this.sparesScrapDetailMainId = ''
      this.queryParam = {}
      this.loadData(1)
    },
    handleApprove: function(record) {
      let  reject, approval;
      reject = this.url.reject
      approval = this.url.approval
      this.$refs.approvalModalForm.showModals(record, reject, approval)
      this.$refs.approvalModalForm.title = '审批'
      this.$refs.approvalModalForm.disableSubmit = false

    },
    approvalModalFormOk() {
      // 通过/驳回时，重载列表
      this.loadData()
      //清空列表选中
      this.onClearSelected()
    },
    loadData(arg) {
      if (!this.url.list) {
        this.$message.error('请设置url.list属性!')
        return
      }
      //加载数据 若传入参数1则加载第一页的内容
      if (arg === 1) {
        this.ipagination.current = 1
      }
      this.onClearSelected()
      var params = this.getQueryParams()//查询条件
      this.loading = true
      getAction(this.url.list, params).then((res) => {
        if (res.success) {
          this.dataSource = res.result.records
          this.ipagination.total = res.result.total
        }
        if (res.code === 510) {
          this.$message.warning(res.message)
        }
        this.loading = false
      })
    },

    getSuperFieldList() {
      let fieldList = []
      fieldList.push({ type: 'string', value: 'createBy', text: '创建人', dictCode: '' })
      fieldList.push({ type: 'datetime', value: 'createTime', text: '创建日期' })
      fieldList.push({ type: 'string', value: 'updateBy', text: '更新人', dictCode: '' })
      fieldList.push({ type: 'datetime', value: 'updateTime', text: '更新日期' })
      fieldList.push({ type: 'string', value: 'num', text: '单据号', dictCode: '' })
      fieldList.push({ type: 'string', value: 'Status', text: '审批状态', dictCode: '' })
      fieldList.push({ type: 'string', value: 'warehouseId', text: '仓库id', dictCode: '' })
      fieldList.push({ type: 'string', value: 'departId', text: '领用部门ID', dictCode: '' })
      fieldList.push({ type: 'string', value: 'userId', text: '领用人员ID', dictCode: '' })
      fieldList.push({ type: 'string', value: 'remark', text: '备注'})
      this.superFieldList = fieldList
    }
  }
}
</script>
<style scoped>
@import '~@assets/less/common.less';
</style>